#! /bin/bash
# Generated by pygopherd.SlackBuild for pygopherd-2.0.16-i486-1McD.tgz on 23-Jan-2007

function upd_conf {
 	# If there's no config file by that name, mv it over:
 	if ! test -f $1; then
 		mv $1.new $1
 	elif diff --brief $1 $1.new; then	# toss the redundant copy
 		rm $1.new
 	fi
 	# Otherwise, we leave the .new copy for the admin to consider...
}

function free_user_id {
 	# Find a free user-ID >= 100 (should be < 1000 so it's not a normal user)
 	local FREE_USER_ID=100
 	while grep --quiet "^.*:.*:$FREE_USER_ID:.*:.*:.*:" /etc/passwd; do
 		let FREE_USER_ID++
 	done
 	echo $FREE_USER_ID
}

# Edit config file with currently used user/group
# (it's not worth leaving a .new file over)
if test -f etc/pygopherd/pygopherd.conf; then
 	TMPFILE=$(mktemp /tmp/pygopherd.XXXXXX)
 	sed '	/^[[:blank:]]*setuid[[:blank:]]*=/	s/=.*/= gopher/
 		/^[[:blank:]]*setgid[[:blank:]]*=/	s/=.*/= gopher/
 		' etc/pygopherd/pygopherd.conf > $TMPFILE
 	if ! diff etc/pygopherd/pygopherd.conf $TMPFILE > /dev/null; then
 		echo 'Changing user/group in /etc/pygopherd/pygopherd.conf to' \
 			'[1mgopher[0m:[1mgopher[0m.' 1>&2
 		cat $TMPFILE > etc/pygopherd/pygopherd.conf	# this doesn't alter perms
 	fi
 	rm $TMPFILE
fi

# Set up group if needed
grep --quiet '^gopher:' etc/group || groupadd gopher

# Set up user: add it if it doesn't exist, update it if it already does.
# In any case, make sure it has or gets a user ID between 100 and 999.
# If username changed, determine old username so we can change it (look
# for entry with homedir /var/gopher).
if OLD_ENTRY=$(grep --max-count=1 '^gopher:' /etc/passwd) \
 	|| OLD_ENTRY=$(grep --max-count=1 \
 		':/var/gopher:[a-z/]*$' /etc/passwd)
then
 	# Modify existing user
 	OLD_USER=$(echo $OLD_ENTRY | cut --fields=1 --delimiter=':')
 	OLD_USER_ID=$(echo $OLD_ENTRY | cut --fields=3 --delimiter=':')
 	OLD_GROUP_ID=$(echo $OLD_ENTRY | cut --fields=4 --delimiter=':')
 	if test "$OLD_USER" != "gopher"; then
 		echo -n "[31mChanging[0m unprivileged user [1m$OLD_USER[0m to" 1>&2
 	else
 		echo -n 'Updating unprivileged user' 1>&2
 	fi
 	echo ' [1mgopher[0m with group [1mgopher[0m.' 1>&2
 	if test $OLD_USER_ID -ge 1000; then
 		USER_ID=$(free_user_id)
 	else
 		USER_ID=$OLD_USER_ID
 	fi
 	usermod -l gopher -g gopher -d /var/gopher \
 		-u $USER_ID -s /bin/false -c 'Python Gopher Daemon' $OLD_USER
else
 	# Add new user
 	echo 'Adding unprivileged user [1mgopher[0m with group [1mgopher[0m.' 1>&2
 	useradd -g gopher -d /var/gopher -u $(free_user_id) \
 		-s /bin/false -c 'Python Gopher Daemon' gopher
fi

# Set up permissions
chown gopher:gopher var/gopher
chown root:gopher 		var/gopher/.plan 		var/gopher/gophermap.new 		etc/pygopherd 		etc/pygopherd/pygopherd.conf.new 		etc/pygopherd/mime.types.new

# Update configuration files
{
	upd_conf etc/pygopherd/mime.types
	upd_conf etc/pygopherd/pygopherd.conf
	upd_conf etc/rc.d/rc.pygopherd
} | sed 's/^/[1mConfig alert: [0m/'
# No need to keep example gophermap file if one was already present
upd_conf var/gopher/gophermap 2>&1 > /dev/null
test -f var/gopher/gophermap.new && rm var/gopher/gophermap.new

# Make us start on boot
if ! grep --quiet 'rc.pygopherd start' etc/rc.d/rc.local; then
 	echo 'Adding Pygopherd to /etc/rc.d/rc.local so it starts at bootup time.' 1>&2
 	{	echo ''
 		echo '# Pygopherd, the Gopher/HTTP server'
 		echo 'test -x /etc/rc.d/rc.pygopherd && /etc/rc.d/rc.pygopherd start'
 	} >> etc/rc.d/rc.local
else
 	echo 'Pygopherd is already in /etc/rc.d/rc.local .'
fi

# Make us stop on shutdown
if ! grep --quiet 'rc.pygopherd stop' etc/rc.d/rc.local_shutdown 2>/dev/null; then
 	echo 'Adding Pygopherd to /etc/rc.d/rc.local_shutdown so it stops at shutdown time.' 1>&2
 	{	echo ''
 		echo '# Pygopherd, the Gopher/HTTP server'
 		echo 'test -x /etc/rc.d/rc.pygopherd && /etc/rc.d/rc.pygopherd stop'
 	} >> etc/rc.d/rc.local_shutdown
else
 	echo 'Pygopherd is already in /etc/rc.d/rc.local_shutdown .'
fi

